Learn R Programming

matlab (version 0.7-8)

jet.colors: MATLAB jet function

Description

Creates a vector of n colors beginning with dark blue, ranging through shades of blue, cyan, green, yellow and red, and ending with dark red.

Usage

jet.colors(n)

Arguments

n
numeric scalar specifying number of colors to be in the palette

Value

  • Returns vector of n colors names. This can be used either to create a user-defined color palette for subsequent graphics, a col= specification in graphics functions or in par.

See Also

palette, par, rgb

Examples

Run this code
jet.colors(4)

Run the code above in your browser using DataLab